@@ -3,6 +3,7 @@
 # Steve Ivy <steveivy@gmail.com>
 # http://monkinetic.com
 
+import logging
 import socket
 import random
 
@@ -20,6 +21,8 @@ class Client(object):
         """
         self.host = host
         self.port = port
+        self.log = logging.getLogger("pystatsd.client")
+        self.udp_sock = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
     
     def timing(self, stat, time, sample_rate=1):
         """
@@ -74,13 +77,10 @@ class Client(object):
         else:
             sampled_data=data
         
-        udp_sock = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
         try:
             for stat, value in sampled_data.iteritems():
                 send_data = "%s:%s" % (stat, value)
-                udp_sock.sendto(send_data, addr)
+                self.udp_sock.sendto(send_data, addr)
         except:
-            import sys
-            from pprint import pprint
-            print "Unexpected error:", pprint(sys.exc_info())
-            pass # we don't care
\ No newline at end of file
+            self.log.exception("unexpected error")
+            pass # we don't care
